<?php

namespace Drupal\service_injector\Constant;

/**
 * Contains all string constants relating to Drupal Core services.
 *
 * Each constant is a direct match to its designated service ID. A class
 * reference is provided in the constant's docblock comment to allow quick
 * access to its service's class.
 *
 * Note that line comments are in use only for the time being. Once the list is
 * complete, these comments will be removed. They are used only to ensure that
 * the ordering of constants in this file matches the one from the Drupal
 * core.services.yml file.
 *
 * @see core/core.services.yml
 */
final class CoreServices {

  /**
   * The Drupal Page Cache Kill Switch service.
   *
   * Line 274.
   *
   * @var string
   *
   * @see \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   */
  public const PAGE_CACHE_KILL_SWITCH = 'page_cache_kill_switch';

  /**
   * The Drupal Config Factory service.
   *
   * Line 295.
   *
   * @var string
   *
   * @see \Drupal\Core\Config\ConfigFactory
   */
  public const CONFIG_FACTORY = 'config.factory';

  /**
   * The Drupal JSON Serialization service.
   *
   * Line 430.
   *
   * @var string
   *
   * @see \Drupal\Component\Serialization\Json
   */
  public const SERIALIZATION_JSON = 'serialization.json';

  /**
   * The Drupal State API service.
   *
   * Line 440.
   *
   * @var string
   *
   * @see \Drupal\Core\State\State
   */
  public const STATE = 'state';

  /**
   * The Drupal Current Path Stack service.
   *
   * Line 459.
   *
   * @var string
   *
   * @see \Drupal\Core\Path\CurrentPathStack
   */
  public const CURRENT_PATH_STACK = 'path.current';

  /**
   * The Drupal Module Installer service.
   *
   * Line 508
   *
   * @var string
   *
   * @see \Drupal\Core\Extension\ModuleInstaller
   */
  public const MODULE_INSTALLER = 'module_installer';

  /**
   * The Drupal Entity Type Manager service.
   *
   * Line 553.
   *
   * @var string
   *
   * @see \Drupal\Core\Entity\EntityTypeManager
   */
  public const ENTITY_TYPE_MANAGER = 'entity_type.manager';

  /**
   * The Symfony Request Stack service.
   *
   * Line 686.
   *
   * @var string
   *
   * @see \Symfony\Component\HttpFoundation\RequestStack
   */
  public const REQUEST_STACK = 'request_stack';

  /**
   * The Drupal Language Manager service.
   *
   * Line 783.
   *
   * @var string
   *
   * @see \Drupal\Core\Language\LanguageManager
   */
  public const LANGUAGE_MANAGER = 'language_manager';

  /**
   * The Drupal Path Matcher service.
   *
   * Line 956.
   *
   * @var string
   *
   * @see \Drupal\Core\Path\PathMatcher
   */
  public const PATH_MATCHER = 'path.matcher';

  /**
   * The Drupal Mail Manager Plugin service.
   *
   * Line 1356.
   *
   * @var string
   *
   * @see \Drupal\Core\Mail\MailManager
   */
  public const PLUGIN_MANAGER_MAIL = 'plugin.manager.mail';

  /**
   * The Drupal Email Validator service.
   *
   * Line 1692.
   *
   * @var string
   *
   * @see \Drupal\Component\Utility\EmailValidator
   */
  public const EMAIL_VALIDATOR = 'email.validator';

}
